---
title: KG이니시스 가상계좌 환불 특약 방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제취소/환불
seo:
  title: KG이니시스 가상계좌 환불 특약 방법
  description: >-
    KG이니시스를 통해 가상계좌 서비스를 이용하실 경우 관련된 이용 특약에 대한 정보를 안내드립니다. 가상계좌 환불 비용 및 환불특약
    신청방법까지 확인해보세요.
tags:
  - KG이니시스
  - 가상계좌
  - 결제취소-환불
pgCompanies:
  - KG이니시스
searchTags:
  - 가상계좌 특약
  - 환불불가
  - 환불불가오류
  - kg이니시스가상계좌
  - 이니시스가상계좌
  - 이니시스환불
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="KG이니시스를 통해 가상계좌 서비스를 이용하실 경우 반드시 가상계좌 서비스 이용 특약을 맺어야 합니다.
환불 시에도 동일하게 반드시 특약을 맺고 환불이 가능합니다.
환불 시 오류가 발생되는 경우 환불 특약이 맺어져 있는지 먼저 확인해 주시기 바랍니다.
" />

### **가상계좌 환불 비용**

가상계좌의 경우 계좌 채번 시 건당 300원씩(VAT 별도)발생되며, 계약 시 설정한 정산 주기에 맞추어 결제수수료를 제외한 금액이 정산되는 형식입니다.

결제대행사에서 고객사와 가상계좌 환불 특약을 맺어 처리되며, 부과되는 환불 수수료 적용 기준은 PG사 시스템을 이용하여 수기로 처리되는 사용료 개념의 수수료라고 생각하시면 될 것 같습니다.

### **가상계좌 환불특약 신청방법**

- [KG이니시스 상점관리자페이지↗](https://iniweb.inicis.com/security/login.do) 접속 > 변경/추가 > 정보 변경 및 서비스 추가
  - 1\. 서비스 추가 및 변경 > 1.2 지불수단추가 및 변경 > 1.2.1 지불수단 추가 및 변경
  - 가상계좌 선택 후 환불서비스(부분취소포함) 사용 선택하여 신청하기 클릭

환불 서비스 이용은 KG이니시스에서 시스템 적용 이후 가능하며 적용 여부는 KG이니시스 계약부서를 통해 정확한 확인이 가능합니다.

- KG이니시스 고객센터 : 1588-4954

